==> guikachu-0.98.0.tar.gz: guikachu-0.98.0/src/resource-ref.h <==
//$Id: resource-ref.h,v 1.1 2001/10/31 20:01:11 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_RESOURCE_REF_H
#define GUIKACHU_RESOURCE_REF_H

#include "property.h"
#include "resource.h"
#include <sigc++/object.h>

namespace Guikachu
{
    namespace Properties
    {
	class ResourceRef: public Property<string>,
			   public SigC::Object
	{
	    Resources::Resource *current_resource;
	    SigC::Connection     current_resource_changed;
	    
	public:
	    ResourceRef (notify_signal_t &notify_signal,
			 const string    &value = "");
	    
	    virtual void set_val (const string &value);
	    inline const string& operator= (const string &value_) { set_val (value_); return value; };	
	    
	private:
	    void resource_created_cb (Resources::Resource *res);
	    void resource_removed_cb (Resources::Resource *res);
	    void resource_changed_cb ();
	};
    }
}

#endif /* !GUIKACHU_RESOURCE_REF_H */

==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/resource-ref.h <==
//$Id: resource-ref.h,v 1.2 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_RESOURCE_REF_H
#define GUIKACHU_RESOURCE_REF_H

#include "property.h"
#include "resource.h"
#include <sigc++/object.h>

namespace Guikachu
{
    namespace Properties
    {
	class ResourceRef: public Property<std::string>,
			   public SigC::Object
	{
	    Resources::Resource *current_resource;
	    SigC::Connection     current_resource_changed;
	    
	public:
	    ResourceRef (notify_signal_t   &notify_signal,
			 const std::string &value = "");
	    
	    virtual void set_val (const std::string &value);
	    inline const std::string& operator= (const std::string &value_) { set_val (value_); return value; };	
	    
	private:
	    void resource_created_cb (Resources::Resource *res);
	    void resource_removed_cb (Resources::Resource *res);
	    void resource_changed_cb ();
	};
    }
}

#endif /* !GUIKACHU_RESOURCE_REF_H */
